@@ -7,7 +7,7 @@ test_that("describe returns tibble", {
   t <- describe(WoJ, ethics_1, ethics_2, ethics_3)
 
   expect_true(tibble::is_tibble(t))
-  expect_equal(dim(t), c(3, 13))
+  expect_equal(dim(t), c(3, 15))
 })
 
 test_that("describe works without specifying variables", {
@@ -15,7 +15,7 @@ test_that("describe works without specifying variables", {
   t <- describe(WoJ)
 
   expect_true(tibble::is_tibble(t))
-  expect_equal(dim(t), c(11, 13))
+  expect_equal(dim(t), c(11, 15))
 })
 
 test_that("describe works with tidyselect helpers", {
@@ -23,9 +23,36 @@ test_that("describe works with tidyselect helpers", {
   t <- describe(WoJ, tidyselect::starts_with("ethics"))
 
   expect_true(tibble::is_tibble(t))
-  expect_equal(dim(t), c(4, 13))
+  expect_equal(dim(t), c(4, 15))
 })
 
+# Describe_cat function
+
+test_that("describe returns tibble", {
+
+  t <- describe_cat(WoJ, reach, employment)
+
+  expect_true(tibble::is_tibble(t))
+  expect_equal(dim(t), c(2, 6))
+})
+
+test_that("describe works without specifying variables", {
+
+  t <- describe_cat(WoJ)
+
+  expect_true(tibble::is_tibble(t))
+  expect_equal(dim(t), c(4, 6))
+})
+
+test_that("describe works with tidyselect helpers", {
+
+  t <- describe_cat(WoJ, tidyselect::contains("country"))
+
+  expect_true(tibble::is_tibble(t))
+  expect_equal(dim(t), c(1, 6))
+})
+
+
 # Skewness & Kurtosis helpers
 
 test_that("skewness returns correct results", {
